pub struct InputFileStatus {
pub fidl_events_received_count: AtomicU64,
pub fidl_events_ignored_count: AtomicU64,
pub fidl_events_unexpected_count: AtomicU64,
pub fidl_events_converted_count: AtomicU64,
pub uapi_events_generated_count: AtomicU64,
pub last_generated_uapi_event_timestamp_ns: AtomicI64,
pub uapi_events_read_count: AtomicU64,
pub last_read_uapi_event_timestamp_ns: AtomicI64,
}Fields
fidl_events_received_count: AtomicU64The number of FIDL events received by this file from Fuchsia input system.
We expect: fidl_events_received_count = fidl_events_ignored_count + fidl_events_unexpected_count + fidl_events_converted_count otherwise starnix ignored events unexpectedly.
fidl_events_unexpected_count should be 0, if not it hints issues from upstream of ui stack.
fidl_events_ignored_count: AtomicU64The number of FIDL events ignored to this module’s representation of TouchEvent.
fidl_events_unexpected_count: AtomicU64The unexpected number of FIDL events reached to this module should be filtered out earlier in the UI stack. It maybe unexpected format or unexpected order.
fidl_events_converted_count: AtomicU64The number of FIDL events converted to this module’s representation of TouchEvent.
uapi_events_generated_count: AtomicU64The number of uapi::input_events generated from TouchEvents.
last_generated_uapi_event_timestamp_ns: AtomicI64The event time of the last generated uapi::input_event.
uapi_events_read_count: AtomicU64The number of uapi::input_events read from this input file by external process.
last_read_uapi_event_timestamp_ns: AtomicI64The event time of the last uapi::input_event read by external process.
Implementations
Sourceimpl InputFileStatus
impl InputFileStatus
pub fn count_received_events(&self, count: u64)
pub fn count_ignored_events(&self, count: u64)
pub fn count_unexpected_events(&self, count: u64)
pub fn count_converted_events(&self, count: u64)
pub fn count_generated_events(&self, count: u64, event_time_ns: i64)
pub fn count_read_events(&self, count: u64, event_time_ns: i64)